@@ -16,7 +16,7 @@ class MakeTestMovieFrames(ScienceTaskL0ToL1Base):
     """
 
     def run(self):
-        for d in range(1, self.num_dsps_repeats + 1):
+        for d in range(1, self.constants.num_dsps_repeats + 1):
             for path, hdu in self.fits_data_read_hdu(tags=[Tag.output(), Tag.dsps_repeat(d)]):
                 header = hdu.header
                 data = hdu.data
