@@ -42,9 +42,7 @@ def generate_214_l0_fits_frame(
     """ Convert S122 header into 214 L0 """
     if data is None:
         data = np.ones((1, 10, 10))
-    hdu = fits.PrimaryHDU(data=data)
     translated_header = translate_spec122_to_spec214_l0(s122_header)
     del translated_header["COMMENT"]
-    for key, value in translated_header.items():
-        hdu.header[key] = value
+    hdu = fits.PrimaryHDU(data=data, header=fits.Header(translated_header))
     return fits.HDUList([hdu])
