@@ -2,8 +2,10 @@
 Tests for the tasks defined in this repo
 """
 import logging
+from dataclasses import dataclass
 from datetime import datetime
 from random import randint
+from typing import Tuple
 
 import numpy as np
 import pytest
@@ -11,7 +13,6 @@ from astropy.io import fits
 from dkist_data_simulator.spec122 import Spec122Dataset
 from dkist_header_validator import spec122_validator
 from dkist_processing_common._util.scratch import WorkflowFileSystem
-from dkist_processing_common.models.constants import BudName
 from dkist_processing_common.models.graphql import InputDatasetResponse
 from dkist_processing_common.models.graphql import RecipeInstanceResponse
 from dkist_processing_common.models.graphql import RecipeRunResponse
@@ -58,6 +59,22 @@ class FakeGQLClient:
         pass
 
 
+@dataclass
+class FakeConstants:
+    num_dsps_repeats: int = 2
+    instrument: str = "TEST"
+    average_cadence: float = 10.0
+    minimum_cadence: float = 10.0
+    maximum_cadence: float = 10.0
+    variance_cadence: float = 0.0
+    stokes_params: Tuple[str] = (
+        "I",
+        "Q",
+        "U",
+        "V",
+    )  # A tuple because lists aren't allowed on dataclasses
+
+
 @pytest.fixture()
 def noop_task():
     return NoOpTask(recipe_run_id=1, workflow_name="noop", workflow_version="VX.Y")
@@ -94,7 +111,7 @@ def generate_calibrated_data_task(tmp_path, recipe_run_id):
         recipe_run_id=recipe_run_id, workflow_name="GenerateCalibratedData", workflow_version="VX.Y"
     ) as task:
         # configure input data
-        task._scratch = WorkflowFileSystem(scratch_base_path=tmp_path)
+        task.scratch = WorkflowFileSystem(scratch_base_path=tmp_path, recipe_run_id=recipe_run_id)
         input_frame_set = Spec122Dataset(
             instrument="vbi",
             dataset_shape=(number_of_frames, 512, 512),
@@ -112,7 +129,7 @@ def generate_calibrated_data_task(tmp_path, recipe_run_id):
         yield task, number_of_frames
         # teardown
         task.scratch.purge()
-        task.constants.purge()
+        task._constants_db.purge()
     # disconnect
 
 
@@ -205,12 +222,15 @@ def write_l1_task(complete_common_header, request):
                 hdu_list=hdul,
                 tags=[Tag.calibrated(), Tag.frame(), Tag.stokes(stokes_params[i])],
             )
-        task.constants[BudName.average_cadence.value] = 10
-        task.constants[BudName.minimum_cadence.value] = 10
-        task.constants[BudName.maximum_cadence.value] = 10
-        task.constants[BudName.variance_cadence.value] = 0
+        task.constants = FakeConstants(
+            average_cadence=10,
+            minimum_cadence=10,
+            maximum_cadence=10,
+            variance_cadence=0,
+            instrument="TEST",
+        )
         yield task, num_of_stokes_params
-        task.constants.purge()
+        task._constants_db.purge()
         task.scratch.purge()
 
 
@@ -238,11 +258,11 @@ def make_movie_frames_task(tmp_path, recipe_run_id):
     with MakeTestMovieFrames(
         recipe_run_id=recipe_run_id, workflow_name="MakeMovieFrames", workflow_version="VX.Y"
     ) as task:
-        task._scratch = WorkflowFileSystem(scratch_base_path=tmp_path)
+        task.scratch = WorkflowFileSystem(scratch_base_path=tmp_path, recipe_run_id=recipe_run_id)
         task.testing_num_dsps_repeats = 10
         task.num_steps = 1
         task.num_exp_per_step = 1
-        task.constants[BudName.num_dsps_repeats.value] = task.testing_num_dsps_repeats
+        task.constants = FakeConstants(num_dsps_repeats=task.testing_num_dsps_repeats)
         ds = S122Headers(
             array_shape=(1, 10, 10),
             num_steps=task.num_steps,
@@ -263,7 +283,7 @@ def make_movie_frames_task(tmp_path, recipe_run_id):
             )
         yield task
         task.scratch.purge()
-        task.constants.purge()
+        task._constants_db.purge()
 
 
 def test_make_movie_frames_task(make_movie_frames_task, mocker):
@@ -289,11 +309,11 @@ def assemble_test_movie_task(tmp_path, recipe_run_id):
     with AssembleTestMovie(
         recipe_run_id=recipe_run_id, workflow_name="AssembleTestMovie", workflow_version="VX.Y"
     ) as task:
-        task._scratch = WorkflowFileSystem(scratch_base_path=tmp_path)
+        task.scratch = WorkflowFileSystem(scratch_base_path=tmp_path)
         task.testing_num_dsps_repeats = 10
         task.num_steps = 1
         task.num_exp_per_step = 1
-        task.constants[BudName.num_dsps_repeats.value] = task.testing_num_dsps_repeats
+        task.constants = FakeConstants(num_dsps_repeats=task.testing_num_dsps_repeats)
         ds = S122Headers(
             array_shape=(1, 10, 10),
             num_steps=task.num_steps,
@@ -314,7 +334,7 @@ def assemble_test_movie_task(tmp_path, recipe_run_id):
             )
         yield task
         task.scratch.purge()
-        task.constants.purge()
+        task._constants_db.purge()
 
 
 def test_assemble_test_movie_task(assemble_test_movie_task, mocker):
