@@ -30,22 +30,22 @@ parse_input_data = Workflow(
 parse_input_data.add_node(task=ParseL0TestInputData, upstreams=None)
 
 # L0Quality Task
-parse_input_data = Workflow(
+quality_l0_metrics = Workflow(
     process_category="test", process_name="quality_l0_metrics", workflow_package=__package__
 )
-parse_input_data.add_node(task=QualityL0Metrics, upstreams=None)
+quality_l0_metrics.add_node(task=QualityL0Metrics, upstreams=None)
 
 # L1Quality Task
-parse_input_data = Workflow(
+quality_l1_metrics = Workflow(
     process_category="test", process_name="quality_l1_metrics", workflow_package=__package__
 )
-parse_input_data.add_node(task=QualityL1Metrics, upstreams=None)
+quality_l1_metrics.add_node(task=QualityL1Metrics, upstreams=None)
 
 # SubmitQuality Task
-parse_input_data = Workflow(
+quality_submit_metrics = Workflow(
     process_category="test", process_name="quality_submit_metrics", workflow_package=__package__
 )
-parse_input_data.add_node(task=SubmitQuality, upstreams=None)
+quality_submit_metrics.add_node(task=SubmitQuality, upstreams=None)
 
 # GenerateL1CalibratedData Task
 generate_calibrated_data = Workflow(
